@@ -2,6 +2,7 @@ from fastapi import FastAPI
 from fastapi.middleware.cors import CORSMiddleware
 
 from apiautomata.routes import echo, home, missing, proxy
+from apiautomata.routes.exchange import instrument_exchange
 
 app = FastAPI()
 
@@ -9,6 +10,7 @@ app.include_router(home.router)
 app.include_router(echo.router)
 app.include_router(proxy.router)
 app.include_router(missing.router)
+app.include_router(instrument_exchange.router)
 
 origins = ['*']
 
