@@ -1,6 +1,7 @@
 import logging
 
 import uvicorn
+from exchangerepo.repository.InstrumentExchangeRepository import InstrumentExchangeRepository
 from missingrepo.repository.MissingRepository import MissingRepository
 
 from apiautomata.holder.ItemHolder import ItemHolder
@@ -20,6 +21,7 @@ class AutomataAPIServer:
         item_holder = ItemHolder()
         item_holder.add(self.options['VERSION'], 'version')
         item_holder.add_entity(MissingRepository(self.options))
+        item_holder.add_entity(InstrumentExchangeRepository(self.options))
 
     def run(self):
         self.log.info('Running')
